@@ -172,6 +172,7 @@ public class FormatData_ja extends ListResourceBundle {
                "\u5927\u6b63",
                "\u662d\u548c",
                "\u5e73\u6210",
+               "\u4ee4\u548c",
             };
         final String[] metaValue_roc_Eras = new String[] {
                "\u6c11\u56fd\u524d",
@@ -227,6 +228,7 @@ public class FormatData_ja extends ListResourceBundle {
                     "T",
                     "S",
                     "H",
+                    "R",
                 }
             },
             { "roc.MonthNarrows", metaValue_buddhist_MonthNarrows },
